@@ -1,5 +1,5 @@
 ###############################################################################
-# (c) Copyright 2020 CERN for the benefit of the LHCb Collaboration           #
+# (c) Copyright 2020-2021 CERN for the benefit of the LHCb Collaboration      #
 #                                                                             #
 # This software is distributed under the terms of the GNU General Public      #
 # Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
@@ -16,8 +16,14 @@ import click
 from LbAPCommon import parse_yaml, render_yaml, validate_yaml
 from pkg_resources import DistributionNotFound, get_distribution
 
+from .checks import checks_exist, perform_checks
 from .log_parsing import show_log_advice
-from .testing import enter_debugging, prepare_reproduce, prepare_test
+from .testing import (
+    do_options_parsing,
+    enter_debugging,
+    prepare_reproduce,
+    prepare_test,
+)
 from .utils import (
     available_productions,
     check_production,
@@ -60,8 +66,8 @@ def main():
 @main.command()
 @click.argument("production_name", type=production_name_type, default="", nargs=1)
 def list(production_name):
-    """List the available production folders by running lb-ap list
-    List the available productions for a specific production by running lb-ap list YOUR_PRODUCTION"""
+    """List the available production folders by running lb-ap list \n
+    List the available productions for a specific production by running lb-ap list <YOUR_PRODUCTION>"""
     inside_ap_datapkg()
 
     if production_name:
@@ -98,12 +104,14 @@ def render(production_name):
     click.echo(render)
     try:
         job_data, check_data = parse_yaml(render)
-        validate_yaml(job_data, check_data, ".", production_name)
+        warnings = validate_yaml(job_data, check_data, ".", production_name)
     except Exception:
         click.secho("Rendered YAML has errors!", fg="red")
         click.secho(f'See "lb-ap validate {production_name}" for details', fg="red")
         raise click.ClickException("Failed to parse and valate YAML")
     else:
+        for warning in warnings:
+            click.secho(f"WARNING: {warning}", fg="yellow")
         click.secho("YAML parsed and validated successfully", fg="green")
 
 
@@ -131,18 +139,26 @@ def validate(production_name):
         click.secho("YAML parsed successfully", fg="green")
 
     try:
-        validate_yaml(job_data, check_data, ".", production_name)
+        warnings = validate_yaml(job_data, check_data, ".", production_name)
     except Exception as e:
         click.secho("Error validating YAML!", fg="red")
         raise click.ClickException(str(e))
     else:
+        for warning in warnings:
+            click.secho(f"WARNING: {warning}", fg="yellow")
         click.secho("YAML validated successfully", fg="green")
 
 
 @main.command()
 @click.argument("production_name", type=production_name_type, nargs=1)
 @click.argument("job_name", type=str, nargs=1)
-@click.option("-i", "--dependent-input", default=None, nargs=1)
+@click.option(
+    "-i",
+    "--dependent-input",
+    default=None,
+    nargs=1,
+    help="Run the test on a specific input file by passing either an LFN or a path to a local file",
+)
 def test(production_name, job_name, dependent_input):
     """Execute a job locally"""
 
@@ -169,6 +185,42 @@ def test(production_name, job_name, dependent_input):
     if result.returncode != 0:
         raise click.ClickException("Execution failed, see above for details")
 
+    # Obtain the right output file name
+    with open(os.path.join(production_name, "info.yaml"), "rt") as fp:
+        raw_yaml = fp.read()
+    prod_data, checks_data = parse_yaml(render_yaml(raw_yaml))
+    warnings = validate_yaml(prod_data, checks_data, ".", production_name)
+    try:
+        job_data = prod_data[job_name]
+    except KeyError:
+        raise click.ClickException(
+            f"Job {job_name} is not found for production {production_name}!"
+        )
+    output_file = job_data["output"].pop()
+
+    # Validating Gaudi options
+    test_ntuple_path = join(out_dir, f"00012345_00006789_1.{output_file}")
+    errors = do_options_parsing(
+        env_cmd,
+        out_dir,
+        join(out_dir, "output.pkl"),
+        test_ntuple_path,
+    )
+    if errors:
+        raise click.ClickException(
+            "Found the following errors when parsing the options:"
+            + "\n  * "
+            + "\n  * ".join(errors)
+        )
+    click.secho("No problems found while validating the Gaudi options", fg="green")
+
+    # Run checks
+    if checks_exist(checks_data):
+        checks_output_dir = join(out_dir, "checks")
+        perform_checks(production_name, job_name, [test_ntuple_path], checks_output_dir)
+
+    for warning in warnings:
+        click.secho(f"WARNING: {warning}", fg="yellow")
     # The functionality of job-dependent job testing relies on out_dir being written
     # in the line below as the final word so please be careful if changing the below line
     click.secho(f"Success! Output can be found in {out_dir}", fg="green")
@@ -177,7 +229,36 @@ def test(production_name, job_name, dependent_input):
 @main.command()
 @click.argument("production_name", type=production_name_type, nargs=1)
 @click.argument("job_name", type=str, nargs=1)
-@click.option("-i", "--dependent-input", default=None, nargs=1)
+@click.argument("test_ntuple_path", type=click.Path(exists=True), nargs=1)
+@click.argument("checks_output_dir", type=click.Path(), nargs=1)
+def check(production_name, job_name, test_ntuple_path, checks_output_dir):
+    """Run checks for a production"""
+    validate_environment()
+    inside_ap_datapkg()
+
+    # Obtain the right output file name
+    with open(os.path.join(production_name, "info.yaml"), "rt") as fp:
+        raw_yaml = fp.read()
+    prod_data, checks_data = parse_yaml(render_yaml(raw_yaml))
+    warnings = validate_yaml(prod_data, checks_data, ".", production_name)
+    for warning in warnings:
+        click.secho(f"WARNING: {warning}", fg="yellow")
+
+    # Run checks
+    if checks_exist(checks_data):
+        perform_checks(production_name, job_name, [test_ntuple_path], checks_output_dir)
+
+
+@main.command()
+@click.argument("production_name", type=production_name_type, nargs=1)
+@click.argument("job_name", type=str, nargs=1)
+@click.option(
+    "-i",
+    "--dependent-input",
+    default=None,
+    nargs=1,
+    help="Run the test on a specific input file by passing either an LFN or a path to a local file",
+)
 def debug(production_name, job_name, dependent_input):
     """Start an interactive session inside the job's environment"""
     validate_environment()
