@@ -1,5 +1,5 @@
 ###############################################################################
-# (c) Copyright 2020 CERN for the benefit of the LHCb Collaboration           #
+# (c) Copyright 2020-2021 CERN for the benefit of the LHCb Collaboration      #
 #                                                                             #
 # This software is distributed under the terms of the GNU General Public      #
 # Licence version 3 (GPL Version 3), copied verbatim in the file "COPYING".   #
@@ -8,6 +8,7 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
+import importlib
 import json
 import os
 import shlex
@@ -20,10 +21,10 @@ from urllib.parse import urlencode, urlparse, urlunparse
 
 import click
 import requests
-from LbAPCommon import parse_yaml, render_yaml, validate_yaml
+from LbAPCommon import cern_sso, parse_yaml, render_yaml, validate_yaml
 from LbAPCommon.hacks import project_uses_cmt
+from LbAPCommon.options_parsing import validate_options
 
-from . import cern_sso
 from .utils import (
     check_production,
     create_output_dir,
@@ -96,9 +97,12 @@ def prepare_test(production_name, job_name, dependent_input=None):
     if job_data.get("turbo"):
         params["turbo"] = job_data["turbo"]
 
-    data = cern_sso.get_with_cookies(
-        urlunparse(ANA_PROD_WEB_URL + ("", urlencode(params), ""))
-    )
+    try:
+        data = cern_sso.get_with_cookies(
+            urlunparse(ANA_PROD_WEB_URL + ("", urlencode(params), ""))
+        )
+    except cern_sso.SSOException as e:
+        raise click.ClickException(str(e))
 
     if job_data["automatically_configure"]:
         config_fn = job_name + "_autoconf.py"
@@ -111,7 +115,8 @@ def prepare_test(production_name, job_name, dependent_input=None):
         )
 
     prod_conf_fn = "prodConf_DaVinci_00012345_00006789_1.py"
-    gaudi_cmd = ["gaudirun.py", "-T", *options, prod_conf_fn]
+    output_pkl = "--output=output.pkl"
+    gaudi_cmd = ["gaudirun.py", "-T", *options, prod_conf_fn, output_pkl]
 
     if len(job_data["output"]) != 1:
         raise NotImplementedError()
@@ -158,11 +163,13 @@ def prepare_reproduce(pipeline_id, production_name, job_name, test_id="latest"):
         f"Reproducing test for test {pipeline_id} {production_name} {job_name}",
         fg="green",
     )
-
-    data = cern_sso.get_with_cookies(
-        f"{cern_sso.ANA_PROD_HOST}/dynamic/{pipeline_id}/{production_name}/"
-        f"{job_name}/{test_id}/reproduce_locally.json"
-    )
+    try:
+        data = cern_sso.get_with_cookies(
+            f"{cern_sso.ANA_PROD_HOST}/dynamic/{pipeline_id}/{production_name}/"
+            f"{job_name}/{test_id}/reproduce_locally.json"
+        )
+    except cern_sso.SSOException as e:
+        raise click.ClickException(str(e))
 
     tmp_dir = tempfile.mkdtemp()
 
@@ -212,30 +219,50 @@ def prepare_reproduce(pipeline_id, production_name, job_name, test_id="latest"):
 
 
 def enter_debugging(out_dir, env_cmd, gaudi_cmd, dependent_job=None):
-    if (
-        dependent_job is not None
-    ):  # This means the requested job depends on another job and has not been told the location of that jobs output.
+    # This means the requested job depends on another job and has not been told
+    # the location of that jobs output
+    if dependent_job is not None:
         raise NotImplementedError(
             "Automatic input creation for job-dependent jobs is not implemented in debug mode \n"
             f"The requested job depends on {dependent_job['job_name']}, please provide the location "
             f"of the output file of a local test of {dependent_job['job_name']} by appending "
             '" -i <file_location>" to the debug command'
         )
-    else:
-        with tempfile.NamedTemporaryFile("wt", delete=False) as fp:
-            bash_env_fn = fp.name
+    with tempfile.NamedTemporaryFile("wt", delete=False) as fp:
+        bash_env_fn = fp.name
+        fp.write("echo\n")
+        fp.write("echo Welcome to analysis productions debug mode:\n")
+        fp.write("echo\n")
+        fp.write("echo The production can be tested by running:\n")
+        fp.write("echo\n")
+        fp.write(f"echo {shlex.quote(shlex.join(gaudi_cmd))}\n")
+        fp.write("echo\n")
+        fp.write(f"rm {shlex.quote(bash_env_fn)}\n")
 
-            fp.write("echo\n")
-            fp.write("echo Welcome to analysis productions debug mode:\n")
-            fp.write("echo\n")
-            fp.write("echo The production can be tested by running:\n")
-            fp.write("echo\n")
-            fp.write(f"echo {shlex.quote(shlex.join(gaudi_cmd))}\n")
-            fp.write("echo\n")
-            fp.write(f"rm {shlex.quote(bash_env_fn)}\n")
+    cmd = env_cmd + ["bash", "--rcfile", bash_env_fn]
+    click.secho(f"Starting lb-run with: {shlex.join(cmd)}", fg="green")
 
-        cmd = env_cmd + ["bash", "--rcfile", bash_env_fn]
-        click.secho(f"Starting lb-run with: {shlex.join(cmd)}", fg="green")
+    os.chdir(out_dir)
+    os.execlp(cmd[0], *cmd)
 
-        os.chdir(out_dir)
-        os.execlp(cmd[0], *cmd)
+
+def do_options_parsing(env_cmd, out_dir, pkl_file, root_file):
+    json_file = join(out_dir, "output.json")
+
+    with importlib.resources.path(
+        "LbAPCommon.options_parsing", "gaudi_pickle_to_json.py"
+    ) as script_path:
+        subprocess.run(
+            env_cmd
+            + [
+                "python",
+                script_path,
+                "--pkl",
+                pkl_file,
+                "--output",
+                json_file,
+                "--debug",
+            ],
+            text=True,
+        )
+    return validate_options(json_file, root_file)
